==> haskell-unixutils-1.54.1-29-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-unixutils.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: Unixutils
version: 1.54.1
id: Unixutils-1.54.1-BaWSDegbc2U12ZNIfJ39TV
key: Unixutils-1.54.1-BaWSDegbc2U12ZNIfJ39TV
license: BSD3
maintainer: jeremy@n-heptane.com
homepage: https://github.com/seereason/haskell-unixutils.git
synopsis: A crude interface between Haskell and Unix-like operating systems
description:
    A collection of useful and mildly useful functions that you might
    expect to find in System.* which a heavy bias towards Unix-type operating systems.
category: System
author: Jeremy Shaw, David Fox
exposed: True
indefinite: False
exposed-modules:
    System.Unix.Chroot System.Unix.Crypt System.Unix.Directory
    System.Unix.FilePath System.Unix.Files System.Unix.KillByCwd
    System.Unix.Misc System.Unix.Mount System.Unix.SpecialDevice
abi: d1f433b2ff5ac31eaa9c43ecfd5eedcb
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/Unixutils-1.54.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/Unixutils-1.54.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/Unixutils-1.54.1
hs-libraries: HSUnixutils-1.54.1-BaWSDegbc2U12ZNIfJ39TV
extra-libraries:
    crypt
depends:
    base-4.10.1.0 bytestring-0.10.8.2 directory-1.3.0.2
    exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq filepath-1.4.1.2
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc process-1.6.1.0
    process-extras-0.7.4-D2fGSm3TmPwLVN9QhSLGMs
    pureMD5-2.1.3-CRfplYMzSYn6Bg2ZRiBq0O
    regex-tdfa-1.2.2-IlR0NGVTXzLcCTtImXEza unix-2.7.2.2
    zlib-0.6.1.2-3jYpKaDVsj2d994OadtMM
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq=349f1b5172af08123dc6c444b05979b3
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             process-extras-0.7.4-D2fGSm3TmPwLVN9QhSLGMs=e03146ad61648e84c2bc2fc9376e72d3
             pureMD5-2.1.3-CRfplYMzSYn6Bg2ZRiBq0O=6b6eeba9ea539a0b4274b77d11c4e0ec
             regex-tdfa-1.2.2-IlR0NGVTXzLcCTtImXEza=c86b19e2cbd14fb97658a1d16e179a53
             unix-2.7.2.2=3df01ca0d7640dab598065ff1b1cffeb
             zlib-0.6.1.2-3jYpKaDVsj2d994OadtMM=fc994ec0331fc01f98e1d968398a1aa2
haddock-interfaces: /usr/share/doc/haskell-unixutils/html/Unixutils.haddock
haddock-html: /usr/share/doc/haskell-unixutils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unixutils-1.54.1-30-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-unixutils.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: Unixutils
version: 1.54.1
id: Unixutils-1.54.1-4PMihyX5n432CFsDoCM1PL
key: Unixutils-1.54.1-4PMihyX5n432CFsDoCM1PL
license: BSD3
maintainer: jeremy@n-heptane.com
homepage: https://github.com/seereason/haskell-unixutils.git
synopsis: A crude interface between Haskell and Unix-like operating systems
description:
    A collection of useful and mildly useful functions that you might
    expect to find in System.* which a heavy bias towards Unix-type operating systems.
category: System
author: Jeremy Shaw, David Fox
exposed: True
indefinite: False
exposed-modules:
    System.Unix.Chroot System.Unix.Crypt System.Unix.Directory
    System.Unix.FilePath System.Unix.Files System.Unix.KillByCwd
    System.Unix.Misc System.Unix.Mount System.Unix.SpecialDevice
abi: 612815b0bdf58ca6b9ddc8c78ddcebbc
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/Unixutils-1.54.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/Unixutils-1.54.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/Unixutils-1.54.1
hs-libraries: HSUnixutils-1.54.1-4PMihyX5n432CFsDoCM1PL
extra-libraries:
    crypt
depends:
    base-4.10.1.0 bytestring-0.10.8.2 directory-1.3.0.2
    exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq filepath-1.4.1.2
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc process-1.6.1.0
    process-extras-0.7.4-D2fGSm3TmPwLVN9QhSLGMs
    pureMD5-2.1.3-CRfplYMzSYn6Bg2ZRiBq0O
    regex-tdfa-1.2.2-IlR0NGVTXzLcCTtImXEza unix-2.7.2.2
    zlib-0.6.2-FRkEyCRDCMJ4V7FViKOnGY
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq=349f1b5172af08123dc6c444b05979b3
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             process-extras-0.7.4-D2fGSm3TmPwLVN9QhSLGMs=e03146ad61648e84c2bc2fc9376e72d3
             pureMD5-2.1.3-CRfplYMzSYn6Bg2ZRiBq0O=6b6eeba9ea539a0b4274b77d11c4e0ec
             regex-tdfa-1.2.2-IlR0NGVTXzLcCTtImXEza=c86b19e2cbd14fb97658a1d16e179a53
             unix-2.7.2.2=3df01ca0d7640dab598065ff1b1cffeb
             zlib-0.6.2-FRkEyCRDCMJ4V7FViKOnGY=a5f6b4f0b968fa7b1bee7784729ec9b2
haddock-interfaces: /usr/share/doc/haskell-unixutils/html/Unixutils.haddock
haddock-html: /usr/share/doc/haskell-unixutils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
